BoxWitness

Struct BoxWitness 

pub struct BoxWitness;
BoxWitness is a zero-sized type that acts as a Higher-Kinded Type (HKT) witness for the Box<T> type constructor. It allows Box to be used with generic functional programming traits like Functor, Applicative, Foldable, and Monad.

By implementing HKT for BoxWitness, we can write generic functions that operate on any type that has the “shape” of Box, without knowing the inner type T.

Constraint

BoxWitness uses NoConstraint, meaning it works with any type T.