VecDequeWitness

Struct VecDequeWitness 

pub struct VecDequeWitness;
Re-exports VecDequeWitness, the HKT witness for VecDeque<T>. VecDequeWitness is a zero-sized type that acts as a Higher-Kinded Type (HKT) witness for the VecDeque<T> type constructor. It allows VecDeque to be used with generic functional programming traits like Functor and Foldable.

By implementing HKT for VecDequeWitness, we can write generic functions that operate on any type that has the “shape” of VecDeque, without knowing the inner type T.